==> hlog-0.10-rc1.tar.gz: hlog-0.10-rc1/country.h <==
/*
 * Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __COUNTRY_H
#define __COUNTRY_H

#include <jeffpc/types.h>
#include <jeffpc/val.h>

struct country_result {
	struct str *prefix;	/* e.g., "K" */
	struct str *name;	/* e.g., "United States" */
	struct str *continent;	/* e.g., "NA" */
	double lat;		/* e.g., 37.53 (degrees, N is positive) */
	double lon;		/* e.g., -91.67 (degrees, E is positive) */
	int32_t tz;		/* e.g., -18000 (seconds, E is positive) */
	uint16_t waz;		/* e.g., 5 */
	uint16_t itu;		/* e.g., 8 */
};

extern int country_load(const char *fname);
extern bool country_lookup(struct str *callsign, struct country_result *result);

static inline bool country_latlon(struct str *callsign, double *lat, double *lon)
{
	struct country_result result;

	if (!country_lookup(callsign, &result))
		return false;

	*lat = result.lat;
	*lon = result.lon;

	return true;
}

#endif

==> hlog-0.11-rc1.tar.gz: hlog-0.11-rc1/country.h <==
/*
 * Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __COUNTRY_H
#define __COUNTRY_H

#include <jeffpc/types.h>
#include <jeffpc/val.h>

struct country_result {
	struct str *prefix;	/* e.g., "AC" */
	struct str *name;	/* e.g., "K" */
	struct str *fullname;	/* e.g., "United States" */
	struct str *continent;	/* e.g., "NA" */
	double lat;		/* e.g., 37.53 (degrees, N is positive) */
	double lon;		/* e.g., -91.67 (degrees, E is positive) */
	int32_t tz;		/* e.g., -18000 (seconds, E is positive) */
	uint16_t waz;		/* e.g., 5 */
	uint16_t itu;		/* e.g., 8 */
	uint16_t code;		/* e.g., 291 */
};

extern int country_load(int dirfd, const char *fname);
extern bool country_lookup(struct str *callsign, struct country_result *result);

static inline bool country_latlon(struct str *callsign, double *lat, double *lon)
{
	struct country_result result;

	if (!country_lookup(callsign, &result))
		return false;

	*lat = result.lat;
	*lon = result.lon;

	return true;
}

#endif
